import { IMetrcFacilityData, IMetrcTransferType, IMetrcCreateTransferPayload } from "@/interfaces";

// Used to verify interfaces against real metrc payloads generated by website
//
// The test runtime isn't relevant, it uses the static type analyzer to verify correctness.


describe('interfaces.ts', () => {
    it('should implement correct types', () => {
        const transferPayload: IMetrcCreateTransferPayload[] = [
            {
                "ShipmentLicenseType": "Licensed",
                "Destinations": [
                    {
                        "ShipmentLicenseType": "Licensed",
                        "RecipientId": "24605",
                        "PlannedRoute": "planned route",
                        "TransferTypeId": "111",
                        "EstimatedDepartureDateTime": "2021-11-03T07:58:40",
                        "EstimatedArrivalDateTime": "2021-11-03T07:58:40",
                        "GrossWeight": "",
                        "GrossUnitOfWeightId": "",
                        "Transporters": [
                            {
                                "TransporterId": "24605",
                                "PhoneNumberForQuestions": "1231231234",
                                "EstimatedArrivalDateTime": "2021-11-03T07:58:40",
                                "EstimatedDepartureDateTime": "2021-11-03T07:58:40",
                                "TransporterDetails": [
                                    {
                                        "DriverName": "driver name",
                                        "DriverOccupationalLicenseNumber": "employee id",
                                        "DriverLicenseNumber": "license number",
                                        "VehicleMake": "make",
                                        "VehicleModel": "model",
                                        "VehicleLicensePlateNumber": "plate"
                                    }
                                ]
                            }
                        ],
                        "Packages": [
                            {
                                "Id": "18870965",
                                "WholesalePrice": "123.45",
                                "GrossWeight": "",
                                "GrossUnitOfWeightId": ""
                            }
                        ]
                    }
                ]
            }
        ]

        const transferType: IMetrcTransferType = {
            "Id": 111,
            "Name": "Wholesale Manifest",
            "TransactionType": "Wholesale",
            "TransactionTypeName": "Wholesale",
            "ForLicensedShipments": true,
            "ForExternalIncomingShipments": true,
            "ShipperLicenseNumberFieldEnabled": true,
            "ShipperLicenseNumberFieldLabel": "Origin Temp. Lic. No.",
            "ShipperLicenseNameFieldEnabled": true,
            "ShipperAddressFieldsEnabled": true,
            "ForExternalOutgoingShipments": true,
            "RecipientLicenseNumberFieldEnabled": true,
            "RecipientLicenseNumberFieldLabel": "Destination Temp. Lic. No.",
            "RecipientLicenseNameFieldEnabled": true,
            "RecipientAddressFieldsEnabled": true,
            "TransporterFieldsEnabled": true,
            "RequiresDestinationGrossWeight": false,
            "RequiresPackagesGrossWeight": false,
            "MinimumWholesalePrice": null,
            "MaximumWholesalePrice": null,
            "FacilityTypes": [
                {
                    "FacilityTypeId": 209,
                    "FacilityTypeName": "Cannabis - Microbusiness License"
                }
            ]
        }

        const facilityData: IMetrcFacilityData = {
            "Id": 201,
            "LicenseNumber": "CDPH-10001131",
            "FacilityName": "LH Manufacturing, LLC",
            "FacilityTypeName": "AM-Type N: Infusion",
            "FacilityType": null,
            "PhysicalAddress": {
                "Id": 201,
                "LicenseId": 0,
                "AddressType": "Physical",
                "Recipient": "",
                "Street1": "2530 Tenth Street, Unit 1-3-4-5",
                "Street2": "",
                "Street3": "",
                "Street4": "",
                "City": "Berkeley",
                "County": "ALAMEDA",
                "State": "CA",
                "PostalCode": "94709",
                "Country": "",
                "AssessorParcelNumber": "",
                "IsArchived": false
            },
            "MainPhoneNumber": "(415) 404-8803",
            "MobilePhoneNumber": "(415) 404-8803"
        }
    });

})
